@rem = '--*-Perl-*--
@echo off
if not "%1"=="" goto continue
echo.
echo GAMS-X Case Script
echo ------------------
echo.
echo Creates a case for a user's model account with inputs specified on
echo the command line.
echo.
echo Syntax:  case Case Model User Input1=Value1 [Input2=Value2 . . .]
echo.
echo where Case is a case name, User is a user name, Model is a model name,
echo and Input? is an input to be used with the case.  If an input is not
echo explicitly specified on the command line, its default value is used.
echo.
echo Example:
echo.
echo case NewCase Ramsey Grog B=0.30 BET=0.925
echo.
echo creates the case HIGHB for the user Grog in the model Ramsey with the 
echo value of the input B set to 0.30 and the value of all other inputs set
echo to their default values.
echo.
echo As with all GAMS-X scripts, it is strongly recommended that you exit
echo GAMS-Tk before using this utility.  See also book.bat.
echo.
goto endofperl
:continue
if "%OS%" == "Windows_NT" goto WinNT
perl -x -S "%0" %1 %2 %3 %4 %5 %6 %7 %8 %9
goto endofperl
:WinNT
perl -x -S "%0" %*
if NOT "%COMSPEC%" == "%SystemRoot%\system32\cmd.exe" goto endofperl
if %errorlevel% == 9009 echo You do not have Perl in your PATH.
goto endofperl
@rem ';
#!perl
#line 14
use GAMS::Tools;

$GAMS = new GAMS::Tools;

$Case = shift @ARGV;
$Model = shift @ARGV;
$User = shift @ARGV;

# Extract arguments defining inputs:

$CaseInputs = {};

for (@ARGV) {
        if (/=/) { ($key,$value) = split /=/
	} else   { $key = shift @ARGV; $value = shift @ARGV }
        print "Setting input $key to $value ...\n";
        $CaseInputs->{$key} = $value;
}

#       Generate the Initial Cases

print "Creating case $Case for model $Model, user $User . . .\n";
$GAMS->Set(
     -User => "$User",
     -Model => "$Model",
     -Case => "$Case",
     -CaseInputs => $CaseInputs
);
$GAMS->NewCase;
$GAMS->Solver;
$GAMS->Quit;

__END__
:endofperl
